The first step to remediation is to identify the context in which the
cookie is being set and determine if it is required by the whole
domain, or just the specific host being tested.

If it is only
required by the host, then the domain flag should be set as such.
Depending on the framework being used, the configuration of this flag
will be modified in different ways.